Macro hetseq::lambda [] [src]

macro_rules! lambda {
    {let $n:ident = |$($(const $anc:ident),* $(mut $anm:ident),* $(: $at:path)*),*| -> $o:ty { $($s:stmt);* }} => { ... };
}

This macro can be used to define lambdas with syntax similar to rust's lambdas Arguments are bound by traits Mainly to use with Functor and Foldable